@@ -2,17 +2,17 @@
 //!
 //! This library provides tools for making requests to the [Telegram Bot API]
 //! (Currently, version `5.3` is supported) with ease. The library is fully
-//! asynchronouns and built using [`tokio`].
+//! asynchronous and built using [`tokio`].
 //!
 //!```toml
-//! teloxide_core = "0.4"
+//! teloxide_core = "0.5"
 //! ```
 //! _Compiler support: requires rustc 1.49+_
 //!
 //! ```
 //! # #[cfg(feature = "auto_send")]
 //! # async {
-//! # let chat_id = 0;
+//! # let chat_id = teloxide_core::types::ChatId(-1);
 //! use teloxide_core::{
 //!     prelude::*,
 //!     types::{DiceEmoji, ParseMode},
@@ -51,8 +51,8 @@
 //! - `erased` — enables [`ErasedRequester`] bot adaptor
 //! - `throttle` — enables [`Throttle`] bot adaptor
 //! - `cache_me` — enables [`CacheMe`] bot adaptor
-//! - `full` — enables all features except `nigthly` and tls-related
-//! - `nightly` — enables nigthly-only features, currently:
+//! - `full` — enables all features except `nightly` and tls-related
+//! - `nightly` — enables nightly-only features, currently:
 //!   - Removes some future boxing using `#![feature(type_alias_impl_trait)]`
 //!   - Used to built docs (`#![feature(doc_cfg, doc_notable_trait)]`)
 //!
@@ -101,6 +101,7 @@ pub use self::{
 };
 
 pub mod adaptors;
+pub mod errors;
 pub mod net;
 pub mod payloads;
 pub mod prelude;
@@ -109,7 +110,6 @@ pub mod types;
 
 // reexported
 mod bot;
-mod errors;
 
 // implementation details
 mod serde_multipart;
