@@ -1,4 +1,4 @@
-//! Telergam API types.
+//! Telegram API types.
 
 pub use allowed_update::*;
 pub use animation::*;
@@ -9,7 +9,6 @@ pub use callback_game::*;
 pub use callback_query::*;
 pub use chat::*;
 pub use chat_action::*;
-pub use chat_id::*;
 pub use chat_invite_link::*;
 pub use chat_join_request::*;
 pub use chat_location::*;
@@ -115,7 +114,6 @@ mod callback_game;
 mod callback_query;
 mod chat;
 mod chat_action;
-mod chat_id;
 mod chat_invite_link;
 mod chat_join_request;
 mod chat_location;
@@ -222,6 +220,14 @@ mod non_telegram_types {
     pub(super) mod until_date;
 }
 
+mod chat_id;
+mod recipient;
+mod user_id;
+
+pub use chat_id::*;
+pub use recipient::*;
+pub use user_id::*;
+
 pub(crate) mod serde_opt_date_from_unix_timestamp {
     use chrono::{DateTime, NaiveDateTime, Utc};
     use serde::{Deserialize, Deserializer, Serialize, Serializer};
@@ -339,3 +345,53 @@ pub(crate) mod option_url_from_string {
         }
     }
 }
+
+pub(crate) mod duration_secs {
+    use std::time::Duration;
+
+    use serde::{Deserialize, Deserializer, Serialize, Serializer};
+
+    pub(crate) fn serialize<S>(this: &Duration, serializer: S) -> Result<S::Ok, S::Error>
+    where
+        S: Serializer,
+    {
+        // match this {
+        //     Some(url) => url.serialize(serializer),
+        //     None => "".serialize(serializer),
+        // }
+        this.as_secs().serialize(serializer)
+    }
+
+    pub(crate) fn deserialize<'de, D>(deserializer: D) -> Result<Duration, D::Error>
+    where
+        D: Deserializer<'de>,
+    {
+        u64::deserialize(deserializer).map(Duration::from_secs)
+    }
+
+    #[test]
+    fn test() {
+        #[derive(Serialize, Deserialize)]
+        struct Struct {
+            #[serde(with = "crate::types::duration_secs")]
+            duration: Duration,
+        }
+
+        {
+            let json = r#"{"duration":0}"#;
+            let duration: Struct = serde_json::from_str(json).unwrap();
+            assert_eq!(duration.duration, Duration::from_secs(0));
+            assert_eq!(serde_json::to_string(&duration).unwrap(), json.to_owned());
+
+            let json = r#"{"duration":12}"#;
+            let duration: Struct = serde_json::from_str(json).unwrap();
+            assert_eq!(duration.duration, Duration::from_secs(12));
+            assert_eq!(serde_json::to_string(&duration).unwrap(), json.to_owned());
+
+            let json = r#"{"duration":1234}"#;
+            let duration: Struct = serde_json::from_str(json).unwrap();
+            assert_eq!(duration.duration, Duration::from_secs(1234));
+            assert_eq!(serde_json::to_string(&duration).unwrap(), json.to_owned());
+        }
+    }
+}
