@@ -1,6 +1,6 @@
 use serde::{Deserialize, Serialize};
 
-use crate::types::ChatId;
+use crate::types::{Recipient, UserId};
 
 /// This object represents the scope to which bot commands are applied.
 ///
@@ -49,20 +49,22 @@ pub enum BotCommandScope {
     AllPrivateChats,
     AllGroupChats,
     AllChatAdministrators,
-    Chat { chat_id: ChatId },
-    ChatAdministrators { chat_id: ChatId },
-    ChatMember { chat_id: ChatId, user_id: i64 },
+    Chat { chat_id: Recipient },
+    ChatAdministrators { chat_id: Recipient },
+    ChatMember { chat_id: Recipient, user_id: UserId },
 }
 
 #[test]
 fn issue_486() {
+    use crate::types::ChatId;
+
     serde_json::to_string(&BotCommandScope::Chat {
-        chat_id: ChatId::Id(0),
+        chat_id: Recipient::Id(ChatId(0)),
     })
     .unwrap();
 
     serde_json::to_string(&BotCommandScope::ChatAdministrators {
-        chat_id: ChatId::Id(0),
+        chat_id: Recipient::Id(ChatId(0)),
     })
     .unwrap();
 }
